@@ -10,13 +10,13 @@ _ = unicode
 
 from cubicweb import Unauthorized
 from cubicweb.view import EntityView, EntityStartupView
-from cubicweb.selectors import (none_rset, implements, relation_possible,
+from cubicweb.selectors import (none_rset, is_instance, relation_possible,
                                 rql_condition)
-from cubicweb.mixins import TreeViewMixIn, TreePathMixIn
 from cubicweb.web import uicfg, box, component
 from cubicweb.web.httpcache import GMTOFFSET
 from cubicweb.web.htmlwidgets import BoxWidget, BoxHtml
 from cubicweb.web.views import primary, baseviews, forms
+from cubicweb.web.views.treeview import BaseTreeView, TreePathView
 
 def folder_tree(req, done=None):
     """yield folder entities according to the tree structure in a depth search
@@ -27,7 +27,7 @@ def folder_tree(req, done=None):
                        'WHERE T is Folder, T2 is Folder, NOT T filed_under T2, '
                        'T name N, T description D')
     for root in rset.entities():
-        for folder in root.prefixiter(done):
+        for folder in root.cw_adapt_to('ITree').prefixiter(done):
             yield folder
 
 
@@ -51,8 +51,8 @@ def subject_filed_under_vocabulary(form, field, limit=None):
     if entity.has_eid() and entity.__regid__ == 'Folder':
         # on an existant folder entity, don't propose itself and descendants.
         # rely on the prefixiter method to fill the `done` set to do so
-        tuple(entity.prefixiter(done))
-    values = sorted((folder.view('combobox'), folder.eid)
+        tuple(entity.cw_adapt_to('ITree').prefixiter(done))
+    values = sorted((folder.view('combobox'), unicode(folder.eid))
                    for folder in folder_tree(form._cw, done))
     if limit is not None:
         return values[:limit]
@@ -72,10 +72,11 @@ _abaa.tag_object_of(('*', 'filed_under', '*'), True)
 # filed_under displayed by FolderPathBarVComponent
 _pvs.tag_subject_of(('*', 'filed_under', '*'), 'hidden')
 _pvs.tag_object_of(('*', 'filed_under', '*'), 'hidden')
+_pvs.tag_attribute(('Folder', 'name'), 'hidden')
 _pvdc.tag_attribute(('Folder', 'description'), {'showlabel': False})
 
 class FolderPrimaryView(primary.PrimaryView):
-    __select__ = implements('Folder')
+    __select__ = is_instance('Folder')
 
     # XXX (syt) useless if we don't activate anymore http caching
     def last_modified(self):
@@ -91,9 +92,10 @@ class FolderPrimaryView(primary.PrimaryView):
             return entity.modification_date
 
     def render_entity_relations(self, entity):
-        self.wview('children', entity.same_type_children(entities=False),
+        itree = entity.cw_adapt_to('ITree')
+        self.wview('children', itree.same_type_children(entities=False),
                    'null')
-        childrenrset = entity.different_type_children(entities=False)
+        childrenrset = itree.different_type_children(entities=False)
         if childrenrset:
             vid = len(childrenrset.column_types(0)) == 1 and 'sameetypelist' or 'list'
             view = self._cw.vreg['views'].select(vid, self._cw, rset=childrenrset)
@@ -102,7 +104,7 @@ class FolderPrimaryView(primary.PrimaryView):
 
 
 class FolderChildrenView(EntityView):
-    __select__ = implements('Folder')
+    __select__ = is_instance('Folder')
     __regid__ = 'children'
     title = None # should not appears in possible views
 
@@ -122,7 +124,7 @@ class FolderChildrenView(EntityView):
 
 
 class FolderTreeItemView(baseviews.ListItemView):
-    __select__ = implements('Folder')
+    __select__ = is_instance('Folder')
     __regid__ = 'treeitem'
 
     def cell_call(self, row, col):
@@ -130,7 +132,7 @@ class FolderTreeItemView(baseviews.ListItemView):
         # don't filter out subfolder, this generate a much more efficient sql
         # query
         totalrs = self._cw.execute('Any count(X) WHERE X filed_under T, '
-                                   'T eid %(x)s', {'x': entity.eid}, 'x')
+                                   'T eid %(x)s', {'x': entity.eid})
         total = totalrs[0][0]
         self.w(u'%s (%s)' % (entity.view('oneline'), total))
         descr = entity.printable_value('description')
@@ -138,9 +140,9 @@ class FolderTreeItemView(baseviews.ListItemView):
             self.w(u'<div>%s</div>' % descr)
 
 
-class FolderTreeView(TreeViewMixIn, EntityStartupView):
+class FolderTreeView(BaseTreeView, EntityStartupView):
     """recursive view displaying a folder tree"""
-    __select__ = none_rset() | implements('Folder')
+    __select__ = none_rset() | is_instance('Folder')
     title = _('Folder_plural')
     # root folder by default
     default_rql = (u'DISTINCT Any T, lower(N), D ORDERBY lower(N) '
@@ -153,23 +155,7 @@ class FolderTreeView(TreeViewMixIn, EntityStartupView):
         if not self.cw_rset:
             self.w('<h3>%s</h3>' % self._cw._('no folder available'))
         else:
-            self.w(u'<ul>\n')
             super(FolderTreeView, self).call(**kwargs)
-            self.w(u'</ul>\n')
-
-
-class FolderPathBarView(TreePathMixIn, EntityView):
-    """one folder in the folder path bar"""
-    __select__ = implements('Folder')
-    separator = u'&nbsp;&gt;&nbsp;'
-
-
-class FolderComboBoxView(FolderPathBarView):
-    """display folder in edition's combobox"""
-    __select__ = implements('Folder')
-    __regid__ = 'combobox'
-    item_vid = 'text'
-    separator = u' > '
 
 
 # folder component ############################################################
